@@ -1,17 +1,17 @@
 /*
  * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
  * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -34,34 +34,34 @@ BombItem::BombItem(Bomb* p_model, KGameRenderer* renderer) : ElementItem (p_mode
     connect(p_model, SIGNAL(bombDetonated(Bomb*)), this, SLOT(startDetonation()));
     connect(p_model, SIGNAL(falling()), this, SLOT(fallingAnimation()));
     connect(this, SIGNAL(bombItemFinished(BombItem*)), p_model, SLOT(slot_detonationCompleted()));
-    
+
     int width = Granatier::CellSize * 0.9;
     int height = Granatier::CellSize * 0.9;
-    if(((int) Granatier::CellSize - width) % 2 != 0)
+    if((static_cast<int>(Granatier::CellSize) - width) % 2 != 0)
     {
         width--;
     }
-    if(((int) Granatier::CellSize - height) % 2 != 0)
+    if((static_cast<int>(Granatier::CellSize) - height) % 2 != 0)
     {
         height--;
     }
     m_itemSizeSet = QSize(width, height);
     m_itemSizeReal = m_itemSizeSet;
-    
+
     m_animationCounter = 0;
     // Define the timer which sets the puls frequency
     m_pulseTimer = new QTimer(this);
     m_pulseTimer->setInterval(nBombPulseTime);
     m_pulseTimer->start();
     connect(m_pulseTimer, &QTimer::timeout, this, &BombItem::pulse);
-    
-    m_explosionTimer = NULL;
+
+    m_explosionTimer = nullptr;
     m_listExplosionTiming.append(Settings::self()->blastTime1());
     m_listExplosionTiming.append(Settings::self()->blastTime2());
     m_listExplosionTiming.append(Settings::self()->blastTime3());
     m_listExplosionTiming.append(Settings::self()->blastTime4());
     m_listExplosionTiming.append(Settings::self()->blastTime5());
-    
+
     m_fallingAnimationCounter = 0;
     m_dudBomb = false;
 }
@@ -94,7 +94,7 @@ void BombItem::pauseAnim()
     if(m_explosionTimer)
     {
         m_explosionTimer->stop();
-    }    
+    }
 }
 
 void BombItem::resumeAnim()
@@ -127,7 +127,7 @@ void BombItem::startDetonation()
     {
         m_pulseTimer->stop();
         delete m_pulseTimer;
-        m_pulseTimer = 0;
+        m_pulseTimer = nullptr;
     }
     m_animationCounter = 0;
     QTransform transform;
@@ -137,21 +137,21 @@ void BombItem::startDetonation()
     setTransform(transform);
     dynamic_cast <Bomb*> (m_model)->setXSpeed(0);
     dynamic_cast <Bomb*> (m_model)->setYSpeed(0);
-    
+
     // Define the timer which sets the explosion frequency
     m_explosionTimer = new QTimer(this);
     m_explosionTimer->setInterval(m_listExplosionTiming.at(0));
     m_explosionTimer->setSingleShot(true);
     m_explosionTimer->start();
     connect(m_explosionTimer, &QTimer::timeout, this, &BombItem::updateAnimation);
-    
+
     int width = Granatier::CellSize * 1.1;
     int height = Granatier::CellSize * 1.1;
-    if(((int) Granatier::CellSize - width) % 2 != 0)
+    if((static_cast<int>(Granatier::CellSize) - width) % 2 != 0)
     {
         width--;
     }
-    if(((int) Granatier::CellSize - height) % 2 != 0)
+    if((static_cast<int>(Granatier::CellSize) - height) % 2 != 0)
     {
         height--;
     }
@@ -181,14 +181,14 @@ void BombItem::pulse()
             {
                 viewHeight--;
             }
-            
+
             //calculate the real item size after change of the render size
             QPointF sceneTopLeft = scene()->views().first()->mapToScene(QPoint(0, 0));
             QPointF sceneBottomRight = scene()->views().first()->mapToScene(QPoint(viewWidth, viewHeight));
-            
+
             qreal sceneWidth = sceneBottomRight.x() - sceneTopLeft.x();
             qreal sceneHeight = sceneBottomRight.y() - sceneTopLeft.y();
-            
+
             // shrink the item
             QTransform transform;
             transform.translate(m_itemSizeSet.width() / 2.0, m_itemSizeSet.height() / 2.0);
@@ -214,7 +214,7 @@ void BombItem::pulse()
         transform.translate(-m_itemSizeReal.width() * (1-m_fallingAnimationCounter*0.02) / 2.0, -m_itemSizeReal.height() * (1-m_fallingAnimationCounter*0.02) / 2.0);
         setTransform(transform);
         m_fallingAnimationCounter++;
-        
+
         if(m_fallingAnimationCounter > 50)
         {
             m_pulseTimer->stop();
@@ -237,7 +237,7 @@ void BombItem::updateAnimation()
     setSpriteKey(strElemetId);
     updateGraphics(scale());
     update(m_x, m_y);
-    
+
     emit animationFrameChanged(this, m_animationCounter);
     m_explosionTimer->setInterval(m_listExplosionTiming.at(m_animationCounter));
     m_explosionTimer->start();
@@ -249,9 +249,9 @@ void BombItem::updateMortar(int nMortarState, int nMortarRampEnd, int nMortarPea
     {
         m_pulseTimer->stop();
         delete m_pulseTimer;
-        m_pulseTimer = 0;
+        m_pulseTimer = nullptr;
     }
-    
+
     if(nMortarState <= 0)
     {
         setVisible(false);
@@ -295,17 +295,17 @@ void BombItem::updateMortarAnimation(int animationCounter, int nMortarRampEnd, i
     {
         mortarZValue = 800;
     }
-    
+
     int frame = animationCounter - nMortarRampEnd;
     int peak = nMortarPeak - nMortarRampEnd;
-    
-    mortarScale = 1.5 - (frame-peak) * (frame-peak) / (qreal) (peak*peak) * 0.5;
+
+    mortarScale = 1.5 - (frame-peak) * (frame-peak) / static_cast<qreal>(peak*peak) * 0.5;
 
     transform.translate(m_itemSizeSet.width() / 2.0, m_itemSizeSet.height() / 2.0);
     setRenderSize(m_renderSize * mortarScale);
     transform.translate(-m_itemSizeReal.width() * mortarScale / 2.0, -m_itemSizeReal.height() * mortarScale / 2.0);
     setTransform(transform);
-    
+
     setVisible(true);
     setZValue(mortarZValue);
 }
