@@ -1,17 +1,17 @@
 /*
  * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
  * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -29,7 +29,7 @@ Cell::~Cell()
 
 bool Cell::isWalkable(Element* p_element) const
 {
-    
+
     if(m_type == Granatier::Cell::WALL)
     {
         return false;
@@ -39,8 +39,8 @@ bool Cell::isWalkable(Element* p_element) const
         foreach(Element* element, m_elements)
         {
             if(element->getType() == Granatier::Element::BLOCK ||
-                (element->getType() == Granatier::Element::BOMB && (p_element == 0 || p_element != element)) ||
-                (element->getType() == Granatier::Element::PLAYER && (p_element == 0 || p_element->getType() != Granatier::Element::PLAYER)))
+                (element->getType() == Granatier::Element::BOMB && (p_element == nullptr || p_element != element)) ||
+                (element->getType() == Granatier::Element::PLAYER && (p_element == nullptr || p_element->getType() != Granatier::Element::PLAYER)))
             {
                 return false;
             }
